@@ -22,16 +22,15 @@
 #'
 #' head(fortify(task))
 #' autoplot(task, bins = 15)
-#' plot(task, bins = 15)
 #' autoplot(task, type = "freq", bins = 15)
 #' autoplot(task, type = "overlay", bins = 15)
 #' autoplot(task, type = "freqpoly", bins = 15)
-autoplot.TaskDens = function(object, type = "dens", ...) {
+autoplot.TaskDens = function(object, type = "dens", ...) { # nolint
   assert_choice(type, c("dens", "freq", "overlay", "freqpoly"))
 
-  p = ggplot(data = object, aes_string(x = object$target_names), ...)
+  p = ggplot(data = object, aes_string(x = object$feature_names), ...)
   # hacky density fix
-  ..density.. <- NULL
+  ..density.. = NULL
 
   if (type == "dens") {
     p + geom_histogram(aes(y = ..density..), fill = "white", color = "black", ...)
@@ -46,9 +45,6 @@ autoplot.TaskDens = function(object, type = "dens", ...) {
   }
 }
 
-#' @importFrom graphics plot
-#' @param x ([mlr3proba::TaskDens]).
-#' @rdname autoplot.TaskDens
 #' @export
 plot.TaskDens = function(x, ...) {
   print(autoplot(x, ...))
